@@ -13,9 +13,9 @@ class UtilTestCase(CubicWebTC):
         """check indexable_entities yield entities as expected"""
         with self.admin_access.cnx() as cnx:
             print(type(cnx))
-            p1 = cnx.create_entity("Person", name=u"p1")
-            p2 = cnx.create_entity("Person", name=u"p3")
-            p3 = cnx.create_entity("Person", name=u"p3")
+            p1 = cnx.create_entity("Person", name="p1")
+            p2 = cnx.create_entity("Person", name="p3")
+            p3 = cnx.create_entity("Person", name="p3")
             drop.reset_mock()
             self.assertEqual(
                 [p.eid for p in indexable_entities(cnx, "Person")],
